

#ifndef SBK_KCOREADDONS_PYTHON_H
#define SBK_KCOREADDONS_PYTHON_H

//workaround to access protected functions
#define protected public

#include <sbkpython.h>
#include <sbkmodule.h>
#include <sbkconverter.h>
// Module Includes
#include <pyside6_qtcore_python.h>

// Bound library includes
#include <kaboutdata.h>
#include <kautosavefile.h>
#include <kbackup.h>
#include <kcompositejob.h>
#include <kcoreaddons.h>
#include <kdirwatch.h>
#include <kfilesystemtype.h>
#include <kfileutils.h>
#include <kformat.h>
#include <kfuzzymatcher.h>
#include <kjob.h>
#include <kjobtrackerinterface.h>
#include <kjobuidelegate.h>
#include <kjsonutils.h>
#include <klibexec.h>
#include <klistopenfilesjob.h>
#include <kmacroexpander.h>
#include <kmemoryinfo.h>
#include <knetworkmounts.h>
#include <kosrelease.h>
#include <kpluginfactory.h>
#include <kpluginmetadata.h>
#include <kprocess.h>
#include <kprocesslist.h>
#include <krandom.h>
#include <kruntimeplatform.h>
#include <ksandbox.h>
#include <kshareddatacache.h>
#include <kshell.h>
#include <ksignalhandler.h>
#include <kstringhandler.h>
#include <ktexttohtml.h>
#include <kurlmimedata.h>
#include <kuser.h>
// Conversion Includes - Primitive Types
#include <QAnyStringView>
#include <qbytearrayview.h>
#include <qchar.h>
#include <qjsonobject.h>
#include <QtCore/qlatin1stringview.h>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <qvariant.h>

// Conversion Includes - Container Types
#include <QHash>
#include <QList>
#include <QMap>
#include <QMultiHash>
#include <QMultiMap>
#include <QPair>
#include <QQueue>
#include <QSet>
#include <QStack>
#include <array>
#include <list>
#include <map>
#include <utility>
#include <unordered_map>
#include <vector>


// Type indices
enum : int {
    SBK_KAboutComponent_IDX                                  = 0,
    SBK_KAboutData_IDX                                       = 1,
    SBK_KAboutLicense_LicenseKey_IDX                         = 3,
    SBK_KAboutLicense_NameFormat_IDX                         = 4,
    SBK_KAboutLicense_VersionRestriction_IDX                 = 5,
    SBK_KAboutLicense_IDX                                    = 2,
    SBK_KAboutPerson_IDX                                     = 6,
    SBK_KAutoSaveFile_IDX                                    = 7,
    SBK_KCoreAddonsKBackup_IDX                               = 8,
    SBK_KCharMacroExpander_IDX                               = 9,
    SBK_KCompositeJob_IDX                                    = 10,
    SBK_KCoreAddonsKCoreAddons_IDX                           = 11,
    SBK_KDirWatch_WatchMode_IDX                              = 14,
    SBK_QFlags_KDirWatch_WatchMode_IDX                       = 77,
    SBK_KDirWatch_Method_IDX                                 = 13,
    SBK_KDirWatch_IDX                                        = 12,
    SBK_KFileSystemType_Type_IDX                             = 16,
    SBK_KCoreAddonsKFileSystemType_IDX                       = 15,
    SBK_KCoreAddonsKFileUtils_IDX                            = 17,
    SBK_KFormat_BinarySizeUnits_IDX                          = 19,
    SBK_KFormat_Unit_IDX                                     = 23,
    SBK_KFormat_UnitPrefix_IDX                               = 24,
    SBK_KFormat_BinaryUnitDialect_IDX                        = 20,
    SBK_KFormat_DurationFormatOption_IDX                     = 22,
    SBK_QFlags_KFormat_DurationFormatOption_IDX              = 79,
    SBK_KFormat_DistanceFormatOption_IDX                     = 21,
    SBK_QFlags_KFormat_DistanceFormatOption_IDX              = 78,
    SBK_KFormat_IDX                                          = 18,
    SBK_KFuzzyMatcher_RangeType_IDX                          = 27,
    SBK_KCoreAddonsKFuzzyMatcher_IDX                         = 25,
    SBK_KFuzzyMatcher_Range_IDX                              = 26,
    SBK_KFuzzyMatcher_Result_IDX                             = 28,
    SBK_KGroupId_IDX                                         = 29,
    SBK_KJob_Unit_IDX                                        = 33,
    SBK_KJob_Capability_IDX                                  = 31,
    SBK_QFlags_KJob_Capability_IDX                           = 80,
    SBK_KJob_KillVerbosity_IDX                               = 32,
    SBK_KJob_IDX                                             = 30,
    SBK_KJobTrackerInterface_IDX                             = 34,
    SBK_KJobUiDelegate_Flag_IDX                              = 36,
    SBK_QFlags_KJobUiDelegate_Flag_IDX                       = 81,
    SBK_KJobUiDelegate_IDX                                   = 35,
    SBK_KCoreAddonsKJsonUtils_IDX                            = 37,
    SBK_KCoreAddonsKLibexec_IDX                              = 38,
    SBK_KListOpenFilesJob_Error_IDX                          = 40,
    SBK_KListOpenFilesJob_IDX                                = 39,
    SBK_KCoreAddonsKMacroExpander_IDX                        = 41,
    SBK_KMacroExpanderBase_IDX                               = 42,
    SBK_KMemoryInfo_IDX                                      = 43,
    SBK_KNetworkMounts_KNetworkMountOption_IDX               = 45,
    SBK_KNetworkMounts_KNetworkMountsType_IDX                = 46,
    SBK_KNetworkMounts_IDX                                   = 44,
    SBK_KOSRelease_IDX                                       = 47,
    SBK_KPluginFactory_ResultErrorReason_IDX                 = 49,
    SBK_KPluginFactory_IDX                                   = 48,
    SBK_KPluginMetaData_KPluginMetaDataOption_IDX            = 51,
    SBK_QFlags_KPluginMetaData_KPluginMetaDataOption_IDX     = 82,
    SBK_KPluginMetaData_IDX                                  = 50,
    SBK_KProcess_OutputChannelMode_IDX                       = 53,
    SBK_KProcess_IDX                                         = 52,
    SBK_KCoreAddonsKProcessList_IDX                          = 54,
    SBK_KProcessList_KProcessInfo_IDX                        = 55,
    SBK_KCoreAddonsKRandom_IDX                               = 56,
    SBK_KCoreAddonsKRuntimePlatform_IDX                      = 57,
    SBK_KCoreAddonsKSandbox_IDX                              = 58,
    SBK_KSandbox_ProcessContext_IDX                          = 59,
    SBK_KSharedDataCache_EvictionPolicy_IDX                  = 61,
    SBK_KSharedDataCache_IDX                                 = 60,
    SBK_KShell_Option_IDX                                    = 64,
    SBK_QFlags_KShell_Option_IDX                             = 83,
    SBK_KShell_Errors_IDX                                    = 63,
    SBK_KCoreAddonsKShell_IDX                                = 62,
    SBK_KSignalHandler_IDX                                   = 65,
    SBK_KCoreAddonsKStringHandler_IDX                        = 66,
    SBK_KTextToHTML_Option_IDX                               = 68,
    SBK_QFlags_KTextToHTML_Option_IDX                        = 84,
    SBK_KCoreAddonsKTextToHTML_IDX                           = 67,
    SBK_KUrlMimeData_DecodeOption_IDX                        = 70,
    SBK_QFlags_KUrlMimeData_DecodeOption_IDX                 = 85,
    SBK_KCoreAddonsKUrlMimeData_IDX                          = 69,
    SBK_KUser_UIDMode_IDX                                    = 72,
    SBK_KUser_UserProperty_IDX                               = 73,
    SBK_KUser_IDX                                            = 71,
    SBK_KUserGroup_IDX                                       = 74,
    SBK_KUserId_IDX                                          = 75,
    SBK_KWordMacroExpander_IDX                               = 76,
    SBK_KCoreAddons_IDX_COUNT                                = 86,
};

// This variable stores all Python types exported by this module.
extern Shiboken::Module::TypeInitStruct *SbkKCoreAddonsTypeStructs;

// This variable stores the Python module object exported by this module.
extern PyObject *SbkKCoreAddonsModuleObject;

// This variable stores all type converters exported by this module.
extern SbkConverter **SbkKCoreAddonsTypeConverters;

// Converter indices
enum [[deprecated]] : int {
    SBK_KCOREADDONS_QLIST_INT_IDX                            = 0, // QList<int>
    SBK_KCOREADDONS_QLIST_KUSERGROUP_IDX                     = 1, // QList<KUserGroup>
    SBK_KCOREADDONS_QLIST_KUSER_IDX                          = 2, // QList<KUser>
    SBK_KCOREADDONS_QMAP_QSTRING_QSTRING_IDX                 = 3, // QMap<QString,QString>
    SBK_KCOREADDONS_QLIST_QURL_IDX                           = 4, // QList<QUrl>
    SBK_KCOREADDONS_QLIST_KPROCESSLIST_KPROCESSINFO_IDX      = 5, // QList<KProcessList::KProcessInfo>
    SBK_KCOREADDONS_QLIST_KABOUTPERSON_IDX                   = 6, // QList<KAboutPerson>
    SBK_KCOREADDONS_QLIST_KPLUGINMETADATA_IDX                = 7, // QList<KPluginMetaData>
    SBK_KCOREADDONS_QHASH_QCHAR_QSTRING_IDX                  = 8, // QHash<QChar,QString>
    SBK_KCOREADDONS_QHASH_QCHAR_QSTRINGLIST_IDX              = 9, // QHash<QChar,QStringList>
    SBK_KCOREADDONS_QHASH_QSTRING_QSTRING_IDX                = 10, // QHash<QString,QString>
    SBK_KCOREADDONS_QHASH_QSTRING_QSTRINGLIST_IDX            = 11, // QHash<QString,QStringList>
    SBK_KCOREADDONS_STD_PAIR_QSTRING_QSTRING_IDX             = 12, // std::pair<QString,QString>
    SBK_KCOREADDONS_QLIST_KFUZZYMATCHER_RANGE_IDX            = 13, // QList<KFuzzyMatcher::Range>
    SBK_KCOREADDONS_QLIST_KJOBPTR_IDX                        = 14, // QList<KJob*>
    SBK_KCOREADDONS_QLIST_KAUTOSAVEFILEPTR_IDX               = 15, // QList<KAutoSaveFile*>
    SBK_KCOREADDONS_QLIST_KABOUTCOMPONENT_IDX                = 16, // QList<KAboutComponent>
    SBK_KCOREADDONS_QLIST_KABOUTLICENSE_IDX                  = 17, // QList<KAboutLicense>
    SBK_KCOREADDONS_QLIST_QVARIANT_IDX                       = 18, // QList<QVariant>
    SBK_KCOREADDONS_QLIST_QSTRING_IDX                        = 19, // QList<QString>
    SBK_KCOREADDONS_QMAP_QSTRING_QVARIANT_IDX                = 20, // QMap<QString,QVariant>
    SBK_KCOREADDONS_CONVERTERS_IDX_COUNT                     = 21,
};

// Converter indices
enum : int {
    SBK_KCoreAddons_QList_int_IDX                            = 0, // QList<int>
    SBK_KCoreAddons_QList_KUserGroup_IDX                     = 1, // QList<KUserGroup>
    SBK_KCoreAddons_QList_KUser_IDX                          = 2, // QList<KUser>
    SBK_KCoreAddons_QMap_QString_QString_IDX                 = 3, // QMap<QString,QString>
    SBK_KCoreAddons_QList_QUrl_IDX                           = 4, // QList<QUrl>
    SBK_KCoreAddons_QList_KProcessList_KProcessInfo_IDX      = 5, // QList<KProcessList::KProcessInfo>
    SBK_KCoreAddons_QList_KAboutPerson_IDX                   = 6, // QList<KAboutPerson>
    SBK_KCoreAddons_QList_KPluginMetaData_IDX                = 7, // QList<KPluginMetaData>
    SBK_KCoreAddons_QHash_QChar_QString_IDX                  = 8, // QHash<QChar,QString>
    SBK_KCoreAddons_QHash_QChar_QStringList_IDX              = 9, // QHash<QChar,QStringList>
    SBK_KCoreAddons_QHash_QString_QString_IDX                = 10, // QHash<QString,QString>
    SBK_KCoreAddons_QHash_QString_QStringList_IDX            = 11, // QHash<QString,QStringList>
    SBK_KCoreAddons_std_pair_QString_QString_IDX             = 12, // std::pair<QString,QString>
    SBK_KCoreAddons_QList_KFuzzyMatcher_Range_IDX            = 13, // QList<KFuzzyMatcher::Range>
    SBK_KCoreAddons_QList_KJobPTR_IDX                        = 14, // QList<KJob*>
    SBK_KCoreAddons_QList_KAutoSaveFilePTR_IDX               = 15, // QList<KAutoSaveFile*>
    SBK_KCoreAddons_QList_KAboutComponent_IDX                = 16, // QList<KAboutComponent>
    SBK_KCoreAddons_QList_KAboutLicense_IDX                  = 17, // QList<KAboutLicense>
    SBK_KCoreAddons_QList_QVariant_IDX                       = 18, // QList<QVariant>
    SBK_KCoreAddons_QList_QString_IDX                        = 19, // QList<QString>
    SBK_KCoreAddons_QMap_QString_QVariant_IDX                = 20, // QMap<QString,QVariant>
    SBK_KCoreAddons_CONVERTERS_IDX_COUNT                     = 21,
};
// Macros for type check

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
namespace Shiboken
{

// PyType functions, to get the PyObjectType for a type T
template<> inline PyTypeObject *SbkType< ::KAboutComponent >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutComponent_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutData >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutData_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutLicense::LicenseKey >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_LicenseKey_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutLicense::NameFormat >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_NameFormat_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutLicense::VersionRestriction >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_VersionRestriction_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutLicense >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutLicense_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAboutPerson >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAboutPerson_IDX]); }
template<> inline PyTypeObject *SbkType< ::KAutoSaveFile >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KAutoSaveFile_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCharMacroExpander >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KCharMacroExpander_IDX]); }
template<> inline PyTypeObject *SbkType< ::KCompositeJob >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KCompositeJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDirWatch::WatchMode >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KDirWatch_WatchMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KDirWatch::WatchMode> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KDirWatch_WatchMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDirWatch::Method >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KDirWatch_Method_IDX]); }
template<> inline PyTypeObject *SbkType< ::KDirWatch >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KDirWatch_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFileSystemType::Type >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFileSystemType_Type_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::BinarySizeUnits >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_BinarySizeUnits_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::Unit >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_Unit_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::UnitPrefix >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_UnitPrefix_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::BinaryUnitDialect >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_BinaryUnitDialect_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::DurationFormatOption >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_DurationFormatOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KFormat::DurationFormatOption> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KFormat_DurationFormatOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat::DistanceFormatOption >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_DistanceFormatOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KFormat::DistanceFormatOption> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KFormat_DistanceFormatOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFormat >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFormat_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFuzzyMatcher::RangeType >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFuzzyMatcher_RangeType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFuzzyMatcher::Range >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFuzzyMatcher_Range_IDX]); }
template<> inline PyTypeObject *SbkType< ::KFuzzyMatcher::Result >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KFuzzyMatcher_Result_IDX]); }
template<> inline PyTypeObject *SbkType< ::KGroupId >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KGroupId_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJob::Unit >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJob_Unit_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJob::Capability >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJob_Capability_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KJob::Capability> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KJob_Capability_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJob::KillVerbosity >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJob_KillVerbosity_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJob >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJobTrackerInterface >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJobTrackerInterface_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJobUiDelegate::Flag >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJobUiDelegate_Flag_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KJobUiDelegate::Flag> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KJobUiDelegate_Flag_IDX]); }
template<> inline PyTypeObject *SbkType< ::KJobUiDelegate >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KJobUiDelegate_IDX]); }
template<> inline PyTypeObject *SbkType< ::KListOpenFilesJob::Error >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KListOpenFilesJob_Error_IDX]); }
template<> inline PyTypeObject *SbkType< ::KListOpenFilesJob >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KListOpenFilesJob_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMacroExpanderBase >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KMacroExpanderBase_IDX]); }
template<> inline PyTypeObject *SbkType< ::KMemoryInfo >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KMemoryInfo_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNetworkMounts::KNetworkMountOption >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KNetworkMounts_KNetworkMountOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNetworkMounts::KNetworkMountsType >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KNetworkMounts_KNetworkMountsType_IDX]); }
template<> inline PyTypeObject *SbkType< ::KNetworkMounts >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KNetworkMounts_IDX]); }
template<> inline PyTypeObject *SbkType< ::KOSRelease >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KOSRelease_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPluginFactory::ResultErrorReason >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KPluginFactory_ResultErrorReason_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPluginFactory >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KPluginFactory_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPluginMetaData::KPluginMetaDataOption >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KPluginMetaData_KPluginMetaDataOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KPluginMetaData::KPluginMetaDataOption> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KPluginMetaData_KPluginMetaDataOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KPluginMetaData >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KPluginMetaData_IDX]); }
template<> inline PyTypeObject *SbkType< ::KProcess::OutputChannelMode >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KProcess_OutputChannelMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KProcess >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KProcess_IDX]); }
template<> inline PyTypeObject *SbkType< ::KProcessList::KProcessInfo >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KProcessList_KProcessInfo_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSandbox::ProcessContext >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KSandbox_ProcessContext_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSharedDataCache::EvictionPolicy >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KSharedDataCache_EvictionPolicy_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSharedDataCache >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KSharedDataCache_IDX]); }
template<> inline PyTypeObject *SbkType< ::KShell::Option >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KShell_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KShell::Option> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KShell_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KShell::Errors >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KShell_Errors_IDX]); }
template<> inline PyTypeObject *SbkType< ::KSignalHandler >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KSignalHandler_IDX]); }
template<> inline PyTypeObject *SbkType< ::KTextToHTML::Option >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KTextToHTML_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KTextToHTML::Option> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KTextToHTML_Option_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUrlMimeData::DecodeOption >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUrlMimeData_DecodeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::QFlags<KUrlMimeData::DecodeOption> >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_QFlags_KUrlMimeData_DecodeOption_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUser::UIDMode >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUser_UIDMode_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUser::UserProperty >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUser_UserProperty_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUser >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUser_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUserGroup >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUserGroup_IDX]); }
template<> inline PyTypeObject *SbkType< ::KUserId >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KUserId_IDX]); }
template<> inline PyTypeObject *SbkType< ::KWordMacroExpander >() { return Shiboken::Module::get(SbkKCoreAddonsTypeStructs[SBK_KWordMacroExpander_IDX]); }

} // namespace Shiboken

QT_WARNING_POP
#endif // SBK_KCOREADDONS_PYTHON_H

